@@ -7,6 +7,9 @@ import org.springframework.stereotype.Controller;
 import org.springframework.web.bind.annotation.*;
 import org.springframework.web.servlet.ModelAndView;
 
+import com.simple.core.base.user.entity.*;
+import com.simple.core.base.user.service.*;
+
 import <%=data.packageName%>.entity.*;
 import <%=data.packageName%>.service.*;
 
